==> agr-center-domain-3.1.0-CLOUD-DEV-20230814.112617-54-sources.jar: com/tydic/dyc/agr/service/agr/AgrGetAgrMainServiceImpl.java <==
package com.tydic.dyc.agr.service.agr;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.tydic.dyc.agr.model.agr.AgrAgrDo;
import com.tydic.dyc.agr.model.agr.IAgrAgrModel;
import com.tydic.dyc.agr.model.agr.qrybo.AgrAgrQryBo;
import com.tydic.dyc.agr.service.agr.bo.AgrGetAgrMainReqBo;
import com.tydic.dyc.agr.service.agr.bo.AgrGetAgrMainRspBo;
import com.tydic.dyc.agr.service.constants.AgrRspConstant;
import com.tydic.dyc.agr.utils.AgrRu;
import com.tydic.dyc.base.exception.BaseBusinessException;
import lombok.extern.ohaotian.HTServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;

/**
 * 作者: dmc
 * 时间: 2022/8/24 11:43
 * 描述:
 */
@HTServiceImpl
public class AgrGetAgrMainServiceImpl implements AgrGetAgrMainService{

    @Autowired
    private IAgrAgrModel iAgrAgrModel;

    @Override
    public AgrGetAgrMainRspBo getAgrMain(AgrGetAgrMainReqBo agrGetAgrMainReqBo) {
        //1 入参检验
        this.validationParam(agrGetAgrMainReqBo);
        //2 调用协议主体查询方法
        AgrAgrDo agrMain = iAgrAgrModel.getAgrMain(AgrRu.js(agrGetAgrMainReqBo, AgrAgrQryBo.class));
        //3 出参装换
        AgrGetAgrMainRspBo agrGetAgrMainRspBo = new AgrGetAgrMainRspBo();
        if (ObjectUtil.isNotEmpty(agrMain)){
            agrGetAgrMainRspBo=AgrRu.js(agrMain,AgrGetAgrMainRspBo.class);
        }
        return agrGetAgrMainRspBo;
    }

    /**
     * 入参检验
     * @param agrGetAgrMainReqBo
     */
    private void validationParam(AgrGetAgrMainReqBo agrGetAgrMainReqBo) {
        if(agrGetAgrMainReqBo.getAgrId() == null && StringUtils.isEmpty(agrGetAgrMainReqBo.getAgrCode()) && StrUtil.isEmpty(agrGetAgrMainReqBo.getRelCode())){
            throw new BaseBusinessException(AgrRspConstant.RESP_CODE_COMMON_PARAM_FIELD_EMPTY_ERROR,"入参对象属性[agrId]和协议编号[agrCode]不能同时为空！");
        }
    }
}

==> agr-center-domain-3.2.2-CLOUD-DEV-20240925.033559-1-sources.jar: com/tydic/dyc/agr/service/agr/AgrGetAgrMainServiceImpl.java <==
package com.tydic.dyc.agr.service.agr;

import cn.hutool.core.map.MapUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.tydic.dyc.agr.model.agr.AgrAgrDo;
import com.tydic.dyc.agr.model.agr.IAgrAgrModel;
import com.tydic.dyc.agr.model.agr.qrybo.AgrAgrQryBo;
import com.tydic.dyc.agr.model.sysDicDictionary.IAgrDictionaryModel;
import com.tydic.dyc.agr.model.sysDicDictionary.qrybo.DicDictionaryBo;
import com.tydic.dyc.agr.service.agr.bo.AgrGetAgrMainReqBo;
import com.tydic.dyc.agr.service.agr.bo.AgrGetAgrMainRspBo;
import com.tydic.dyc.agr.service.constants.AgrCommConstant;
import com.tydic.dyc.agr.service.constants.AgrRspConstant;
import com.tydic.dyc.agr.utils.AgrRu;
import com.tydic.dyc.base.exception.BaseBusinessException;
import lombok.extern.ohaotian.HTServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 作者: dmc
 * 时间: 2022/8/24 11:43
 * 描述:
 */
@HTServiceImpl
public class AgrGetAgrMainServiceImpl implements AgrGetAgrMainService{

    @Autowired
    private IAgrAgrModel iAgrAgrModel;

    @Autowired
    private IAgrDictionaryModel iAgrDictionaryModel;

    @Override
    public AgrGetAgrMainRspBo getAgrMain(AgrGetAgrMainReqBo agrGetAgrMainReqBo) {
        //1 入参检验
        this.validationParam(agrGetAgrMainReqBo);
        //2 调用协议主体查询方法
        AgrAgrDo agrMain = iAgrAgrModel.getAgrMain(AgrRu.js(agrGetAgrMainReqBo, AgrAgrQryBo.class));
        //3 出参装换
        AgrGetAgrMainRspBo agrGetAgrMainRspBo = new AgrGetAgrMainRspBo();
        if (ObjectUtil.isNotEmpty(agrMain)){
            agrGetAgrMainRspBo=AgrRu.js(agrMain,AgrGetAgrMainRspBo.class);
            // 翻译
            translation(agrGetAgrMainRspBo);
        }
        return agrGetAgrMainRspBo;
    }

    private void translation(AgrGetAgrMainRspBo agrGetAgrMainRspBo) {
        List<String> pcodeList = new ArrayList<>(12);
        if (ObjectUtil.isNotNull(agrGetAgrMainRspBo.getAgrType())) {
            pcodeList.add(AgrCommConstant.SysDicDictionaryPCode.AGR_TYPE_PCODE);
        }
        Map<String, Map<String, DicDictionaryBo>> dicMap = this.iAgrDictionaryModel.selectByPCodeListToMap(pcodeList);
        // 协议分类
        agrGetAgrMainRspBo.setAgrTypeStr(MapUtil.isEmpty(dicMap.get(AgrCommConstant.SysDicDictionaryPCode.AGR_TYPE_PCODE)) ? null : dicMap.get(AgrCommConstant.SysDicDictionaryPCode.AGR_TYPE_PCODE).get(agrGetAgrMainRspBo.getAgrType().toString()).getTitle());
    }

    /**
     * 入参检验
     * @param agrGetAgrMainReqBo
     */
    private void validationParam(AgrGetAgrMainReqBo agrGetAgrMainReqBo) {
        if(agrGetAgrMainReqBo.getAgrId() == null && StringUtils.isEmpty(agrGetAgrMainReqBo.getAgrCode()) && StrUtil.isEmpty(agrGetAgrMainReqBo.getRelCode())){
            throw new BaseBusinessException(AgrRspConstant.RESP_CODE_COMMON_PARAM_FIELD_EMPTY_ERROR,"入参对象属性[agrId]和协议编号[agrCode]不能同时为空！");
        }
    }
}
